@@ -8,7 +8,10 @@ from sciencebeam_parser.document.semantic_document import (
     SemanticSection,
     SemanticSectionTypes
 )
-from sciencebeam_parser.models.fulltext.training_data import FullTextTeiTrainingDataGenerator
+from sciencebeam_parser.models.fulltext.training_data import (
+    FullTextTeiTrainingDataGenerator,
+    FullTextTrainingTeiParser
+)
 from sciencebeam_parser.models.model import Model
 
 from sciencebeam_parser.models.data import (
@@ -36,6 +39,9 @@ class FullTextModel(Model):
     def get_tei_training_data_generator(self) -> FullTextTeiTrainingDataGenerator:
         return FullTextTeiTrainingDataGenerator()
 
+    def get_training_tei_parser(self) -> FullTextTrainingTeiParser:
+        return FullTextTrainingTeiParser()
+
     def update_section_with_entity_blocks(
         self,
         parent_section: SemanticSection,
